<template>
  <ProTabs
    v-model="queryState.mineSignType"
    name="home-tab"
    :showPaneContent="false"
    class="home-tabs"
    isTransparent
    title-gutter="12"
    title-scroll
  >
    <ProTabPane :title="`全部`" :pane-key="MineSignType.All"></ProTabPane>
    <ProTabPane :title="`待确认`" :pane-key="MineSignType.WaitConfirm"></ProTabPane>
    <ProTabPane :title="`待签约`" :pane-key="MineSignType.WaitSign"></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
    :key="queryState.mineSignType"
  >
    <template #renderItem="{ item }">
      <TaskCard>
        <template #actions>
          <div class="task-card-actions-text" :style="{ color: MineSignTypeColor[10] }">
            {{ MineSignTypeText[10] }}
          </div>
        </template>
      </TaskCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { TaskCard, ProTabs, ProTabPane } from '@12333/components';
import { useUserStore } from '@/stores/modules/user';
import { MineSignType, MineSignTypeColor, MineSignTypeText } from './constants';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as orderServices from '@12333/services/api/Order';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  mineSignType: MineSignType.All,
});

const userStore = useUserStore();

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          queryState.mineSignType === MineSignType.All
            ? { property: 'isRecommend', order: OrderInputType.Desc }
            : { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
  }
);
</script>

<style lang="scss">
@import '@/styles/common.scss';

.task-card-actions-text {
  font-size: 24px;
  line-height: 42px;
}
</style>
